pub struct Ring<T, const N: usize, const MP: usize, const MC: usize> { /* private fields */ }
Appends an element to the back of the Ring.
Returns Err if the Ring is full or in critical section.
Appends an element to the back of the Ring.
Removes the first element and returns it.
Returns Err if the Ring is empty or in critical section.
Removes the first element and returns it.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.